mfyreport介绍

1、什么是mfyreport?
mfyreport是基于unittest开发的的一个功能扩展库，关于mfyreport最初在开发的时候，在开发的过程中参考了木先生的思路。后续还会持续的扩展和开发一些新的功能，目前实现了以下功能：

HTML测试报告生成\
unittest数据驱动\
发送测试结果及报告到邮箱


2、安装mfyreport\
mfyreport是基于python3.7开发的，安装前请确认你的python版本>3.7

3、安装命令\
3.1、pip install mfyreport\
3.2、通过工具pycharm下载